@@ -1487,8 +1487,8 @@ def runtestswithappsurify(*args):
                 startrunspecific = argv[k+1] + endspecificrun
                 print("fall back command = "+ startrunall)
                 print("prioritized run = "+ startrunspecific)
-            if argv[k] == "--runnewtests":
-                runnewtests = argv[k+1]
+            #if argv[k] == "--runnewtests":
+            #    runnewtests = argv[k+1]
             if argv[k] == "--help":
                 echo("please see url for more details on this script and how to execute your tests with appsurify - https://github.com/Appsurify/AppsurifyCI")
 
@@ -1701,6 +1701,8 @@ def runtestswithappsurify(*args):
                 split_string = testsrun.find("|Name=",max_length)
                 setval = testsrun[:split_string]
                 testsrun = testsrun[split_string:]
+                if variable_num == 1:
+                    print (f'##vso[task.setvariable variable={azure_variable}]{azurefilter}{setval}')
                 print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}{setval}')
                 variable_num = variable_num + 1
             print (f'##vso[task.setvariable variable={azure_variable}{variable_num}]{azurefilter}{testsrun}')
